% ----- -----
% PMSM
% -----
% Input data
Mot_Rs = 0.165; % Stator winding resistance 
Mot_Lm1 = 13e-3; % Average single phase magnetizing inductance
Mot_Lm2 = 0; % Varying magnetizing inductance due to saliency
Mot_Lls = 6.1e-3; % Leakage inductance
Mot_Vll = 7200; % Line voltage
Mot_p = 2; % Number of poles
Mot_J = 5.7; % Inertia 5.7
Mot_Is = 237; % Rated current
Mot_fn = 85; % Synchronous frequency [Hz]
Mot_Pn = 2100e3; % Rated power [kW]
% -----
% Parameter calculations
Mot_Lmd = 3/2*(Mot_Lm1+Mot_Lm2); % d-axis magnetizing inductance
Mot_Lmq = 3/2*(Mot_Lm1-Mot_Lm2); % q-axis magnetizing inductance
Mot_Ld = Mot_Lls+Mot_Lmd; % d-axis inductance
Mot_Lq = Mot_Lls+Mot_Lmq; % q-axis inductance
Mot_Vph = Mot_Vll/sqrt(3); % Phase voltage
Mot_Vm = Mot_Vph*sqrt(2); % Rated voltage amplitude
Mot_Im = Mot_Is * sqrt(2); % Rated current amplitude
Mot_pp = Mot_p/2; % Pole pair
Mot_nn = 120*Mot_fn/Mot_p; % Synchronous speed
Mot_wm = Mot_nn*2*pi/60; % Rated mechanical speed
Mot_wr = Mot_pp*Mot_wm; % Rated electrical speed
Mot_PMFlux = (Mot_Vm-Mot_Rs*Mot_Im)/Mot_wr; % Permanent magnet flux [Vs]
Mot_Tn = Mot_Pn/Mot_wm; % Rated torque
Mot_H = Mot_wm*Mot_J/(2*Mot_Tn); % Inertia constant
Mot_Tb = (3*Mot_Vm*Mot_Im/2)/Mot_wm; % Base torque

% ----- -----
% Load
% -----
% Input data
Load_Tbrk = 0.2*Mot_Tn; % Breakaway friction torque 0.2
Load_ThetaE_start = 0; % Starting position, electrical
% -----
% Parameter calculations
Load_ThetaM_start = Load_ThetaE_start/Mot_pp; % Starting position, mech.
Load_K = Mot_Tn/(Mot_wm^2); % Load torque constant

% ----- -----
% Transformers
% -----
% Topside transformer input data
T1_n=5.3/24.4; % Turns ratio
T1_L1r=4.098107155497063e-04; % Primary winding inductance real value
T1_L2r=0.008685827967592; % Secondary winding inductance real value
T1_R1r=0.013764100000000; % Primary winding resistance base value
T1_R2r=0.291726400000000; % Secondary winding resistance base value
% Subsea transformer input data
T2_n=22/6.9; % Turns ratio
T2_L1r=0.010250719211562; % Primary winding inductance real value
T2_L2r=0.001008340375336; % Secondary winding inductance real value
T2_R1r=0.242000000000000; % Primary winding resistance base value
T2_R2r=0.023805000000000; % Secondary winding resistance base value

% ----- -----
% Line
% -----
% Input data
L_r = 0.21; % Resistance [ohm/km]
L_l = 0.776; % Inductance [mH/km]
L_c = 0.14; % Capacitance [microF/km]
L_len = 21.4; % Length [km] , 21.4
% -----
% Parameter calculations
L_R = L_r*L_len; % Equivalent resistance
L_L = L_l*1e-3*L_len; % Equivalent Inductance

% ----- -----
% System parameters and simulation
% -----
% System parameters
Sys_Rtot = Mot_Rs+T2_R2r+(T2_R1r+L_R+T1_R2r)/(T2_n^2)+T1_R1r/ ...
    ((T1_n^2)*(T2_n^2)); % Total equivalent system resistance
Sys_Ltot = T2_L2r+(T2_L1r+L_L+T1_L2r)/(T2_n^2)+T1_L1r/ ...
    ((T1_n^2)*(T2_n^2)); % Total equivalent system inductance
% -----
% Frequency ramp and simulation time
t_acc = 0.01;% Frequency ramp slope [pu/sec] 0.01
t_sim = 1/t_acc;
t_acc_HzPerSec = t_acc*Mot_fn;

% ----- -----
% Scalar control - Partial and delayed voltage boosting
% -----
% Input data
Sca_Kb = 12.0567; % Back emf to voltage drop ratio
% Direct connection parameters
Sca_dir_wrb = Sca_Kb*Mot_Rs*Mot_Im/Mot_PMFlux;
Sca_dir_fb = Sca_dir_wrb/(2*pi);
Sca_dir_Fb = (Mot_Im*Mot_Rs+Sca_dir_wrb*Mot_PMFlux)/(Sca_dir_wrb*Mot_PMFlux);
Sca_dir_Vmb = Sca_dir_wrb*Sca_dir_Fb*Mot_PMFlux;
Sca_dir_Fb2 = (Mot_Im*Mot_Rs+2*pi*Mot_fn*Mot_PMFlux-Sca_dir_Vmb)/(Mot_fn-Sca_dir_fb);
calc_fb=6.5;
calc_kb=(calc_fb*2*pi)/(Mot_Rs*Mot_Im/Mot_PMFlux);
% Full connection
Sca_full_wrb = Sca_Kb*Sys_Rtot*Mot_Im/Mot_PMFlux;
Sca_full_fb = Sca_full_wrb/(2*pi);
Sca_full_Fb = (Mot_Im*Sys_Rtot+Sca_full_wrb*Mot_PMFlux)/(Sca_full_wrb*Mot_PMFlux);
Sca_full_Vmb = Sca_full_wrb*Sca_full_Fb*Mot_PMFlux;
Sca_full_Fb2 = (Mot_Im*Sys_Rtot+2*pi*Mot_fn*Mot_PMFlux-Sca_full_Vmb)/(Mot_fn-Sca_full_fb);
calc_fb2=42;
calc_kb2=(calc_fb2*2*pi)/(Sys_Rtot*Mot_Im/Mot_PMFlux);

% ----- -----
% Vector control
% -----
% Input data
Fs = 10e3;      %Inverter's Swithcing frequency 10[kHz]
id_ref=0;
B = 0.001; % Viscous friction coefficient
Is_qm = sqrt(Mot_Im^2-id_ref^2);
Te_m= 3/2*Mot_pp*(Mot_PMFlux*Is_qm+(Mot_Ld-Mot_Lq)*id_ref*Is_qm);
Ts=1e-5;
% Current PI parameters
alpha_i = 2*pi*Fs/10;    %Parameter used for Kp & Ki
Kpc_d = alpha_i*Mot_Ld;    %Prop.constant of d-axis current reg.
Kic_d = alpha_i*Mot_Rs;    %Int. constant of d-axis current reg.
Kpc_q = alpha_i*Mot_Lq;    %Prop. constant of q-axis current reg.
Kic_q = alpha_i*Mot_Rs;    %Int. constant of q-axis current reg.
% Speed PI parameters
alpha_w = alpha_i/10;    %Parameter used for Kp & Ki
Kpw = alpha_w*Mot_J;      %Prop. constant of speed reg.
Kiw = alpha_w*B;      %Int. constant of speed reg.
